# delimit ;
	set more 1;
	version 10.0;
	
	clear;
	
	set mem 400m;
	
/* Set paths as global strings */

	global mainpath "C:\Users\Vik\Documents\Current Work\AER AUM\";								
	
/* Opening the Dataset Downloaded from AER website */
	
	use "$mainpath\BCHHS_data.dta", clear;
	
/* Generating Age Squared */

	gen agesq=age*age;
	la var agesq "age squared";

/* Generating log wages */

	gen lnw=ln(earning);
	la var lnw "log wages";

/* Reshaping the Dataset */

	reshape wide earning-lnw, i(family) j(twinno);	
	
/* Generate average education of each twin pair */

	gen avehigh = (highqua1+highqua2)/2;
	gen avhight= (twihigh1 + twihigh2)/2;
	
/* Generating Within-Twin Variables used in estimating within-twin regressions */

	gen dlnw=lnw1-lnw2;
	la var dlnw "within-twin difference in log wages";

	gen dhighqua=highqua1-highqua2;
	la var dhighqua "within-twin difference in self reported education";

	gen dtwihigh=twihigh1-twihigh2;
	la var dtwihigh "within-twin difference in twins report of co-twins education";

 	gen dmarried=married1-married2;
	la var dmarried "within-twin difference in married status";

	gen dpart=part1-part2;
	la var dpart "within-twin difference in part time work status";

 	gen dexp= own_exp1- own_exp2;
	la var dexp "within-twin difference in experience";

	gen dlse= LNandSE1- LNandSE2;
	la var dlse "within-twin difference in living in London and South East";

	gen dwage=earning1-earning2;
	la var dwage "within-twin difference in wages";
	
/* Generating Absolute Within-Twin Differences */

	gen awage=abs(dwage);
	la var awage "absolute within-twin differences in wages";
	
	gen ahighqua=abs(dhighqua);
	la var ahighqua "absolute within-twin difference in education";
	
/* Save regression results in log file--here estimate wage equations including average twin pair education
   to proxy for unobservables and compare to within-twin estimates from tabl 1 */	

	log using "$mainpath\Table1_AUM_Extra.smcl", replace;
	
/* Table 1, row 1, replicating original results on the full sample */

	reshape long;

	reg lnw highqua avehigh age agesq;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq;

	reg lnw highqua avehigh age agesq LNandSE married own_exp part if dhighqua~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq LNandSE married own_exp part if dhighqua~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	
/* Table 1, row 2, drop twin pair with difference in absolute wage of greater than 90 */

	reg lnw highqua avehigh age agesq if awage<90;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq if awage<90;

	reg lnw highqua avehigh age agesq LNandSE married own_exp part if awage<90 & dhighqua~=. & dtwihigh~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq LNandSE married own_exp part if awage<90 & dhighqua~=. & dtwihigh~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;


/* Table 1, row 3, drop twin pair with difference in absolute wage of greater than 75 */

	reg lnw highqua avehigh age agesq if awage<75;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq if awage<75;

	reg lnw highqua avehigh age agesq LNandSE married own_exp part if awage<75 & dhighqua~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq LNandSE married own_exp part if awage<75 & dhighqua~=. & dtwihigh~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;


/* Table 1, row 4, drop twin pair with difference in absolute wage of greater than 65 */

	reg lnw highqua avehigh age agesq if awage<65;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq if awage<65;

	reg lnw highqua avehigh age agesq LNandSE married own_exp part if awage<65 & dhighqua~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq LNandSE married own_exp part if awage<65 & dhighqua~=. & dtwihigh~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;


/* Table 1, row 5, drop twin pair with difference in absolute wage of greater than 60 */

	reg lnw highqua avehigh age agesq if awage<60;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq if awage<60;

	reg lnw highqua avehigh age agesq LNandSE married own_exp part if awage<60 & dhighqua~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	ivreg lnw (highqua avehigh=twihigh avhight) age agesq LNandSE married own_exp part if awage<60 & dhighqua~=. & dtwihigh~=. & dlse~=. & dmarried~=. & dexp~=. & dpart~=.;

	log close;				